@@ -6,22 +6,22 @@ class SDK:
     def __init__(self, merchant: dict, processor: str = None):
         # Si se le indica el procesador
         self.processor = processor
-        if processor == 'mercadopago':
+        if processor == 'mercadopago' and merchant['credentials']['mercadopago']['active']:
             self._sdk = MercadoPagoSDK(merchant)
             return
-        elif processor == 'mp_marketplace':
+        elif processor == 'mp_marketplace' and merchant['credentials']['mp_marketplace']['active']:
             self._sdk = MercadoPagoSDK(merchant, marketplace=True)
             return
-        elif processor == 'decidir':
+        elif processor == 'decidir' and merchant['credentials']['decidir']['active']:
             self._sdk = DecidirSDK(merchant)
             return
-        # Si no utiliza el preferrred_processor que tenga el merchant
-        if 'credentials' in merchant and merchant['credentials']['preferred_processor'] == 'decidir':
-            self._sdk = DecidirSDK(merchant)
-            self.processor = 'decidir'
-        else:
-            self._sdk = MercadoPagoSDK(merchant)
-            self.processor = 'mercadopago'
+        # # Si no utiliza el preferrred_processor que tenga el merchant
+        # if 'credentials' in merchant and merchant['credentials']['preferred_processor'] == 'decidir':
+        #     self._sdk = DecidirSDK(merchant)
+        #     self.processor = 'decidir'
+        # else:
+        #     self._sdk = MercadoPagoSDK(merchant)
+        #     self.processor = 'mercadopago'
 
     def customer(self):
         return self._sdk.customer()
