@@ -7,7 +7,13 @@ from ..response import ok, error
 
 def _format(response):
     response['amount'] = response['amount'] / 100
-    #response['status_detail'] = 'accredited' if response['status'] == 'approved' else response['status']
+    response['date_created'] = response['date']
+    response['status_detail'] = response['status']
+    if response['status'] == 'accredited':
+        response['status'] = 'approved'
+        response['status_detail'] = 'accredited'
+    elif response['status'] == 'approved':
+        response['status_detail'] = 'not_accredited'
 
     return response
 
