@@ -12,11 +12,10 @@ class CardToken:
             card['id'] = card['mercadopago_id']
 
         data = {
-            "card_id": card['id']
+            "id": card['id']
         }
         card_token_response = self.sdk.card_token().create(data)
 
         if card_token_response["status"] > 299:
-            return error("Falló la creación de token de la tarjeta.",)
-
-        return ok(card_token_response["response"]["id"])
+            return error("Falló la creación de token de la tarjeta.")
+        return ok(card_token_response["response"])
